import { Jwt } from 'jsonwebtoken';
/**
 * @packageDocumentation Function to validate access token received from azure active directory. Useful when you're using a msal library to authenticate users on the frontend and you wanna verify Microsoft tokens in the API.
 */
/**
 * The interface represents required fields to process access token validation
 *
 * @public
 */
export interface IValidationOptions {
    /**
     * Only present in v1.0 tokens. The application ID of the client using the token. The application can act as itself or on behalf of a user. The application ID typically represents an application object, but it can also represent a service principal object in Azure AD.
     */
    applicationId: string;
    /**
     * Identifies the intended recipient of the token - its audience. In v2.0 tokens, this is always the client ID of the API, while in v1.0 tokens it can be the client ID or the resource URI used in the request, depending on how the client requested the token.
     */
    audience: string;
    /**
     * The set of scopes exposed by your application for which the client application has requested (and received) consent.
     */
    scopes: string[];
    /**
     * Your Microsoft 365 tenant ID is a globally unique identifier (GUID) that is different than your organization name or domain.
     */
    tenantId: string;
}
/**
 * The interface represents required fields to process access token validation
 *
 * @public
 */
export interface IB2CValidationOptions {
    /**
     * Identifies the intended recipient of the token - its audience. In v2.0 tokens, this is always the client ID of the API, while in v1.0 tokens it can be the client ID or the resource URI used in the request, depending on how the client requested the token.
     */
    clientID: string;
    policyName: string;
    /**
     * The set of scopes exposed by your application for which the client application has requested (and received) consent.
     */
    scopes: string[];
    /**
     * Your Microsoft 365 tenant ID is a globally unique identifier (GUID) that is different than your organization name or domain.
     */
    tenantId: string;
    tenantName: string;
}
/**
 * Validate azure active directory access token
 *
 * @param accessToken - valid access token received from azure
 * @param validationOptions - the interface represents required fields to process access token validation
 *
 * @public
 */
export default function validate(accessToken: string, { applicationId, audience, scopes, tenantId }: IValidationOptions): Promise<Jwt>;
/**
 * Validate azure active directory access token
 *
 * @param accessToken - valid access token received from azure
 * @param validationOptions - the interface represents required fields to process access token validation
 *
 * @public
 */
export declare function validateB2C(accessToken: string, { clientID, policyName, scopes, tenantId, tenantName }: IB2CValidationOptions): Promise<Jwt>;
